@@ -1,7 +1,7 @@
 /****************************************************************************
 **
 ** Copyright (C) 2012 Jeremy Lainé <jeremy.laine@m4x.org>
-** Contact: http://www.qt-project.org/legal
+** Contact: https://www.qt.io/licensing/
 **
 ** This file is part of the QtNetwork module of the Qt Toolkit.
 **
@@ -10,30 +10,28 @@
 ** Licensees holding valid commercial Qt licenses may use this file in
 ** accordance with the commercial license agreement provided with the
 ** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and Digia.  For licensing terms and
-** conditions see http://qt.digia.com/licensing.  For further information
-** use the contact form at http://qt.digia.com/contact-us.
+** a written agreement between you and The Qt Company. For licensing terms
+** and conditions see https://www.qt.io/terms-conditions. For further
+** information use the contact form at https://www.qt.io/contact-us.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 2.1 as published by the Free Software
-** Foundation and appearing in the file LICENSE.LGPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU Lesser General Public License version 2.1 requirements
-** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
-**
-** In addition, as a special exception, Digia gives you certain additional
-** rights.  These rights are described in the Digia Qt LGPL Exception
-** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
+** General Public License version 3 as published by the Free Software
+** Foundation and appearing in the file LICENSE.LGPL3 included in the
+** packaging of this file. Please review the following information to
+** ensure the GNU Lesser General Public License version 3 requirements
+** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
 **
 ** GNU General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
-**
+** General Public License version 2.0 or (at your option) the GNU General
+** Public license version 3 or any later version approved by the KDE Free
+** Qt Foundation. The licenses are as published by the Free Software
+** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
+** included in the packaging of this file. Please review the following
+** information to ensure the GNU General Public License requirements will
+** be met: https://www.gnu.org/licenses/gpl-2.0.html and
+** https://www.gnu.org/licenses/gpl-3.0.html.
 **
 ** $QT_END_LICENSE$
 **
@@ -78,11 +76,11 @@ static void qt_qdnsmailexchangerecord_sort(QList<QDnsMailExchangeRecord> &record
 
         // Determine the slice of records with the current preference.
         QList<QDnsMailExchangeRecord> slice;
-        const quint16 slicePreference = records[i].preference();
+        const quint16 slicePreference = records.at(i).preference();
         for (int j = i; j < records.size(); ++j) {
-            if (records[j].preference() != slicePreference)
+            if (records.at(j).preference() != slicePreference)
                 break;
-            slice << records[j];
+            slice << records.at(j);
         }
 
         // Randomize the slice of records.
@@ -121,13 +119,13 @@ static void qt_qdnsservicerecord_sort(QList<QDnsServiceRecord> &records)
 
         // Determine the slice of records with the current priority.
         QList<QDnsServiceRecord> slice;
-        const quint16 slicePriority = records[i].priority();
+        const quint16 slicePriority = records.at(i).priority();
         unsigned int sliceWeight = 0;
         for (int j = i; j < records.size(); ++j) {
-            if (records[j].priority() != slicePriority)
+            if (records.at(j).priority() != slicePriority)
                 break;
-            sliceWeight += records[j].weight();
-            slice << records[j];
+            sliceWeight += records.at(j).weight();
+            slice << records.at(j);
         }
 #ifdef QDNSLOOKUP_DEBUG
         qDebug("qt_qdnsservicerecord_sort() : priority %i (size: %i, total weight: %i)",
@@ -139,15 +137,15 @@ static void qt_qdnsservicerecord_sort(QList<QDnsServiceRecord> &records)
             const unsigned int weightThreshold = qrand() % (sliceWeight + 1);
             unsigned int summedWeight = 0;
             for (int j = 0; j < slice.size(); ++j) {
-                summedWeight += slice[j].weight();
+                summedWeight += slice.at(j).weight();
                 if (summedWeight >= weightThreshold) {
 #ifdef QDNSLOOKUP_DEBUG
                     qDebug("qt_qdnsservicerecord_sort() : adding %s %i (weight: %i)",
-                           qPrintable(slice[j].target()), slice[j].port(),
-                           slice[j].weight());
+                           qPrintable(slice.at(j).target()), slice.at(j).port(),
+                           slice.at(j).weight());
 #endif
                     // Adjust the slice weight and take the current record.
-                    sliceWeight -= slice[j].weight();
+                    sliceWeight -= slice.at(j).weight();
                     records[i++] = slice.takeAt(j);
                     break;
                 }
@@ -156,6 +154,9 @@ static void qt_qdnsservicerecord_sort(QList<QDnsServiceRecord> &records)
     }
 }
 
+const char *QDnsLookupPrivate::msgNoIpV6NameServerAdresses =
+    QT_TRANSLATE_NOOP("QDnsLookupRunnable", "IPv6 addresses for nameservers are currently not supported");
+
 /*!
     \class QDnsLookup
     \brief The QDnsLookup class represents a DNS lookup.
@@ -283,9 +284,21 @@ QDnsLookup::QDnsLookup(Type type, const QString &name, QObject *parent)
 
 /*!
     \fn QDnsLookup::QDnsLookup(Type type, const QString &name, const QHostAddress &nameserver, QObject *parent)
-    \internal
+    \since 5.4
+    Constructs a QDnsLookup object for the given \a type, \a name and
+    \a nameserver and sets \a parent as the parent object.
 */
 
+QDnsLookup::QDnsLookup(Type type, const QString &name, const QHostAddress &nameserver, QObject *parent)
+    : QObject(*new QDnsLookupPrivate, parent)
+{
+    Q_D(QDnsLookup);
+    qRegisterMetaType<QDnsLookupReply>();
+    d->name = name;
+    d->type = type;
+    d->nameserver = nameserver;
+}
+
 /*!
     Destroys the QDnsLookup object.
 
